import React from "react";
import ReactDOM from "react-dom/client";
import { createBrowserRouter, RouterProvider } from "react-router-dom";
import SummaryRoute from "./routes/SummaryRoute";
import BrowseRoute from "./routes/BrowseRoute";
import SettingsRoute from "./routes/SettingsRoute";
import SocketHandler from "./assets/classes/SocketHandler";
import MapRoute from "./routes/MapRoute";

// Root
const root = ReactDOM.createRoot(document.getElementById("root"));

// Socket handler
console.log("Connecting to WebSocket server.");
const socket = new WebSocket("ws://localhost:9000");
socket.addEventListener("open", function (event) {
  console.log("Websocket connected.");
  console.log("Welcome to Belden Jukebox!");
  init();
});

// Initialize the app
const init = () => {
  const socketHandler = new SocketHandler(socket);

  const router = createBrowserRouter([
    {
      path: "/",
      element: <SummaryRoute socketHandler={socketHandler}></SummaryRoute>,
      // errorElement: <ErrorRoute></ErrorRoute>,
    },
    {
      path: "/browse",
      element: <BrowseRoute socketHandler={socketHandler}></BrowseRoute>,
      // errorElement: <ErrorRoute></ErrorRoute>,
    },
    {
      path: "/settings",
      element: <SettingsRoute socketHandler={socketHandler}></SettingsRoute>,
      // errorElement: <ErrorRoute></ErrorRoute>,
    },
    {
      path: "/map",
      element: <MapRoute socketHandler={socketHandler}></MapRoute>,
      // errorElement: <ErrorRoute></ErrorRoute>,
    },
  ]);

  root.render(
    <div>
      <RouterProvider router={router} />
    </div>
  );
};
